from kfp import compiler
from kfp import components
from kfp import dsl


@dsl.component
def addition_component(num1: int, num2: int) -> int:
    return num1 + num2


@dsl.pipeline(name='addition-pipeline')
def my_pipeline(a: int, b: int, c: int = 10):
    add_task_1 = addition_component(num1=a, num2=b)
    add_task_2 = addition_component(num1=add_task_1.output, num2=c)


cmplr = compiler.Compiler()


def test_compile_pipeline():
    cmplr.compile(my_pipeline, package_path='local/my_pipeline.yaml')
    assert True


def test_compile_component():
    cmplr.compile(addition_component,
                  package_path='local/addition_component.yaml')
    assert True


if __name__ == '__main__':
    test_compile_pipeline()
    test_compile_component()
    print(
        components.load_component_from_file(
            'local/addition_component.yaml').component_spec)

    # client = kfp.Client("")
    # # run the pipeline in v2 compatibility mode
    # client.create_run_from_pipeline_func(
    #     my_pipeline,
    #     arguments={'a': 7, 'b': 8, 'c': 9},
    #     mode=kfp.dsl.PipelineExecutionMode.V2_COMPATIBLE,
    # )
